@@ -71,16 +71,35 @@ namespace Rcpp {
         }
 
         /** construct a string from a single CHARSXP SEXP */
-        String(SEXP charsxp) : data(charsxp), valid(true), buffer_ready(false), enc(Rf_getCharCE(charsxp)) {
+        String(SEXP charsxp) : data(R_NilValue) {
+            if (TYPEOF(charsxp) == STRSXP) {
+                data = STRING_ELT(charsxp, 0);
+            } else if (TYPEOF(charsxp) == CHARSXP) {
+                data = charsxp;
+            }
+
             if (::Rf_isString(data) && ::Rf_length(data) != 1)
                 throw ::Rcpp::not_compatible("expecting a single value");
+
+            valid = true;
+            buffer_ready = false;
+            enc = Rf_getCharCE(data);
             Rcpp_PreserveObject(data);
             RCPP_STRING_DEBUG("String(SEXP)");
         }
 
-        String(SEXP charsxp, const std::string& enc) : data(charsxp), valid(true), buffer_ready(false) {
+        String(SEXP charsxp, const std::string& enc) : data(R_NilValue) {
+            if (TYPEOF(charsxp) == STRSXP) {
+                data = STRING_ELT(charsxp, 0);
+            } else if (TYPEOF(charsxp) == CHARSXP) {
+                data = charsxp;
+            }
+
             if (::Rf_isString(data) && ::Rf_length(data) != 1)
                 throw ::Rcpp::not_compatible("expecting a single value");
+
+            valid = true;
+            buffer_ready = false;
             Rcpp_PreserveObject(data);
             set_encoding(enc);
             RCPP_STRING_DEBUG("String(SEXP)");
@@ -217,6 +236,14 @@ namespace Rcpp {
             setBuffer(); buffer += CHAR(proxy_sexp); valid = false;
             return *this;
         }
+        inline String& operator+=(const const_StringProxy& proxy) {
+            RCPP_STRING_DEBUG("String::operator+=(const StringProxy&)");
+            if (is_na()) return *this;
+            SEXP proxy_sexp = proxy;
+            if (proxy_sexp == NA_STRING) { data = Rcpp_ReplaceObject(data, NA_STRING); valid = true; buffer_ready = false; return *this;}
+            setBuffer(); buffer += CHAR(proxy_sexp); valid = false;
+            return *this;
+        }
         inline String& operator+=(SEXP x) {
             RCPP_STRING_DEBUG("String::operator+=(SEXP)");
             if (is_na()) return *this;
@@ -235,7 +262,8 @@ namespace Rcpp {
             RCPP_STRING_DEBUG_2("String::replace_first(const char* = '%s' , const char* = '%s')", s, news);
             if (is_na()) return *this;
             setBuffer();
-            size_t index = buffer.find_first_of(s);
+            std::string s2 = std::string(s);
+            size_t index = std::distance(buffer.begin(), std::search(buffer.begin(), buffer.end(), s2.begin(), s2.end()));
             if (index != std::string::npos) buffer.replace(index, strlen(s), news);
             valid = false;
             return *this;
@@ -260,7 +288,8 @@ namespace Rcpp {
             RCPP_STRING_DEBUG_2("String::replace_last(const char* = '%s' , const char* = '%s')", s, news);
             if (is_na()) return *this;
             setBuffer();
-            size_t index = buffer.find_last_of(s);
+            std::string s2 = std::string(s);
+            size_t index = std::distance(buffer.begin(), std::find_end(buffer.begin(), buffer.end(), s2.begin(), s2.end()));
             if (index != std::string::npos) buffer.replace(index, strlen(s), news);
             valid = false;
             return *this;
@@ -286,10 +315,13 @@ namespace Rcpp {
             RCPP_STRING_DEBUG_2("String::replace_all(const char* = '%s' , const char* = '%s')", s, news);
             if (is_na()) return *this;
             setBuffer();
-            size_t lens = strlen(s), len_news = strlen(news), index = buffer.find(s);
-            while(index != std::string::npos) {
-                buffer.replace(index, lens, news);
-                index = buffer.find(s, index + len_news);
+            std::string s2 = std::string(s);
+            std::string::iterator iter = buffer.begin();
+            while(true) {
+                iter = std::search(iter, buffer.end(), s2.begin(), s2.end());
+                if (iter == buffer.end()) break;
+                size_t index = std::distance(buffer.begin(), iter);
+                if (index != std::string::npos) buffer.replace(index, strlen(s), news);
             }
             valid = false;
             return *this;
@@ -548,4 +580,24 @@ namespace Rcpp {
 
 } // Rcpp
 
+/** hash can be in std or std::tr1 */
+#if defined(RCPP_USING_CXX11) || defined(HAS_TR1)
+namespace std
+{
+#ifndef RCPP_USING_CXX11
+namespace tr1 {
+#endif
+    template <>
+    struct hash<Rcpp::String>
+    {
+        size_t operator()(const Rcpp::String & s) const{
+            return hash<string>()(s.get_cstring());
+        }
+    };
+#ifndef RCPP_USING_CXX11
+}
+#endif
+}
+#endif
+
 #endif
