@@ -137,7 +137,12 @@ inline SEXP get_last_call(){
 
 inline SEXP get_exception_classes( const std::string& ex_class) {
     Rcpp::Shield<SEXP> res( Rf_allocVector( STRSXP, 4 ) );
+    
+    #ifndef RCPP_USING_UTF8_ERROR_STRING
     SET_STRING_ELT( res, 0, Rf_mkChar( ex_class.c_str() ) ) ;
+    #else
+    SET_STRING_ELT( res, 0, Rf_mkCharLenCE( ex_class.c_str(), ex_class.size(), CE_UTF8 ) );
+    #endif
     SET_STRING_ELT( res, 1, Rf_mkChar( "C++Error" ) ) ;
     SET_STRING_ELT( res, 2, Rf_mkChar( "error" ) ) ;
     SET_STRING_ELT( res, 3, Rf_mkChar( "condition" ) ) ;
@@ -146,8 +151,13 @@ inline SEXP get_exception_classes( const std::string& ex_class) {
 
 inline SEXP make_condition(const std::string& ex_msg, SEXP call, SEXP cppstack, SEXP classes){
     Rcpp::Shield<SEXP> res( Rf_allocVector( VECSXP, 3 ) ) ;
-
-    SET_VECTOR_ELT( res, 0, Rf_mkString( ex_msg.c_str() ) ) ;
+    #ifndef RCPP_USING_UTF8_ERROR_STRING
+        SET_VECTOR_ELT( res, 0, Rf_mkString( ex_msg.c_str() ) ) ;
+    #else
+        Rcpp::Shield<SEXP> ex_msg_rstring( Rf_allocVector( STRSXP, 1 ) ) ;
+        SET_STRING_ELT( ex_msg_rstring, 0, Rf_mkCharLenCE( ex_msg.c_str(), ex_msg.size(), CE_UTF8 ) );
+        SET_VECTOR_ELT( res, 0, ex_msg_rstring ) ;
+    #endif
     SET_VECTOR_ELT( res, 1, call ) ;
     SET_VECTOR_ELT( res, 2, cppstack ) ;
 
@@ -174,10 +184,17 @@ inline SEXP exception_to_r_condition( const std::exception& ex){
 
 inline SEXP string_to_try_error( const std::string& str){
     using namespace Rcpp;
-
-    Rcpp::Shield<SEXP> simpleErrorExpr( Rf_lang2(::Rf_install("simpleError"), Rf_mkString(str.c_str())) );
+    
+    #ifndef RCPP_USING_UTF8_ERROR_STRING
+        Rcpp::Shield<SEXP> simpleErrorExpr( Rf_lang2(::Rf_install("simpleError"), Rf_mkString(str.c_str())) );
+        Rcpp::Shield<SEXP> tryError( Rf_mkString( str.c_str() ) );
+    #else
+        Rcpp::Shield<SEXP> tryError( Rf_allocVector( STRSXP, 1 ) ) ;
+        SET_STRING_ELT( tryError, 0, Rf_mkCharLenCE( str.c_str(), str.size(), CE_UTF8 ) );
+        Rcpp::Shield<SEXP> simpleErrorExpr( Rf_lang2(::Rf_install("simpleError"), tryError ));
+   #endif
+    
     Rcpp::Shield<SEXP> simpleError( Rf_eval(simpleErrorExpr, R_GlobalEnv) );
-    Rcpp::Shield<SEXP> tryError( Rf_mkString( str.c_str() ) );
     Rf_setAttrib( tryError, R_ClassSymbol, Rf_mkString("try-error") ) ;
     Rf_setAttrib( tryError, Rf_install( "condition") , simpleError ) ;
 
@@ -247,57 +264,57 @@ namespace Rcpp{
         Rf_warning( tfm::format(fmt, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10).c_str() );
     }
 
-    inline void stop(const std::string& message) {
+    inline void NORET stop(const std::string& message) {
         throw Rcpp::exception(message.c_str());
     }
     
     template <typename T1>
-    inline void stop(const char* fmt, const T1& arg1) {
+    inline void NORET stop(const char* fmt, const T1& arg1) {
         throw Rcpp::exception( tfm::format(fmt, arg1 ).c_str() );
     }
     
     template <typename T1, typename T2>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2 ).c_str() );
     }
     
     template <typename T1, typename T2, typename T3>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3).c_str() );
     }
     
     template <typename T1, typename T2, typename T3, typename T4>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3, arg4).c_str() );
     }
     
     template <typename T1, typename T2, typename T3, typename T4, typename T5>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3, arg4, arg5).c_str() );
     }
     
     template <typename T1, typename T2, typename T3, typename T4, typename T5, typename T6>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3, arg4, arg5, arg6).c_str() );
     }
     
     template <typename T1, typename T2, typename T3, typename T4, typename T5, typename T6, typename T7>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3, arg4, arg5, arg6, arg7).c_str() );
     }
     
     template <typename T1, typename T2, typename T3, typename T4, typename T5, typename T6, typename T7, typename T8>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7, const T8& arg8) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7, const T8& arg8) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8).c_str() );
     }
     
     template <typename T1, typename T2, typename T3, typename T4, typename T5, typename T6, typename T7, typename T8, typename T9>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7, const T8& arg8, const T9& arg9) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7, const T8& arg8, const T9& arg9) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9).c_str() );
     }
     
     template <typename T1, typename T2, typename T3, typename T4, typename T5, typename T6, typename T7, typename T8, typename T9, typename T10>
-    inline void stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7, const T8& arg8, const T9& arg9, const T10& arg10) {
+    inline void NORET stop(const char* fmt, const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4, const T5& arg5, const T6& arg6, const T7& arg7, const T8& arg8, const T9& arg9, const T10& arg10) {
         throw Rcpp::exception( tfm::format(fmt, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10).c_str() );
     }
 }
