@@ -576,6 +576,18 @@ std::string character_iterator1( CharacterVector letters ){
     return res ;
 }
 
+// [[Rcpp::export]]
+std::string character_const_iterator1( const CharacterVector letters ){
+    std::string res ;
+    CharacterVector::const_iterator first = letters.begin() ;
+    CharacterVector::const_iterator last = letters.end() ;
+    while( first != last ){
+        res += *first ;
+        ++first ;
+    }
+    return res ;
+}
+
 
 // [[Rcpp::export]]
 std::string character_iterator2( CharacterVector letters ){
@@ -583,6 +595,12 @@ std::string character_iterator2( CharacterVector letters ){
     return res ;
 }
 
+// [[Rcpp::export]]
+std::string character_const_iterator2( const CharacterVector letters ){
+    std::string res(std::accumulate(letters.begin(), letters.end(), std::string()));
+    return res ;
+}
+
 // [[Rcpp::export]]
 CharacterVector character_reverse( CharacterVector y ){
     std::reverse( y.begin(), y.end() ) ;
@@ -805,3 +823,8 @@ String vec_print_integer(IntegerVector v) {
     buf << v;
     return buf.str();
 }
+
+// [[Rcpp::export]]
+IntegerVector vec_subset(IntegerVector x, IntegerVector y) {
+    return x[y - 1];
+}
