@@ -1,4 +1,4 @@
-#!/usr/bin/r -t
+#!/usr/bin/env r
 #
 # Copyright (C) 2010 - 2014  Dirk Eddelbuettel, Romain Francois and Kevin Ushey
 #
@@ -94,22 +94,43 @@ if (.runThisTest) {
 	checkEquals( runit_NumericMatrix_row( x ), sum( x[1,] ), msg = "iterating over a row" )
     }
 
+    test.NumericMatrix.row.const <- function(){
+	x <- matrix( 1:16 + .5, ncol = 4 )
+	checkEquals( runit_NumericMatrix_row_const( x ), sum( x[1,] ), msg = "iterating over a row" )
+    }
+
     test.CharacterMatrix.row <- function(){
 	m <- matrix( letters, ncol = 2 )
 	checkEquals( runit_CharacterMatrix_row(m), paste( m[1,], collapse = "" ), msg = "CharacterVector::Row" )
     }
 
+    test.CharacterMatrix.row.const <- function(){
+	m <- matrix( letters, ncol = 2 )
+	checkEquals( runit_CharacterMatrix_row_const(m), paste( m[1,], collapse = "" ), msg = "CharacterVector::Row" )
+    }
+
     test.List.row <- function(){
 	m <- lapply( 1:16, function(i) seq(from=1, to = i ) )
 	dim( m ) <- c( 4, 4 )
 	checkEquals( runit_GenericMatrix_row( m ), 1 + 0:3*4, msg = "List::Row" )
     }
 
+    test.List.row.const <- function(){
+	m <- lapply( 1:16, function(i) seq(from=1, to = i ) )
+	dim( m ) <- c( 4, 4 )
+	checkEquals( runit_GenericMatrix_row_const( m ), 1 + 0:3*4, msg = "List::Row" )
+    }
+
     test.NumericMatrix.column <- function(){
 	x <- matrix( 1:16 + .5, ncol = 4 )
 	checkEquals( runit_NumericMatrix_column( x ), sum( x[,1] ) , msg = "iterating over a column" )
     }
 
+    test.NumericMatrix.column.const <- function(){
+	x <- matrix( 1:16 + .5, ncol = 4 )
+	checkEquals( runit_NumericMatrix_column_const( x ), sum( x[,1] ) , msg = "iterating over a column" )
+    }
+
     test.NumericMatrix.cumsum <- function(){
 	x <- matrix( 1:8 + .5, ncol = 2 )
 	checkEquals( runit_NumericMatrix_cumsum( x ), t(apply(x, 1, cumsum)) , msg = "cumsum" )
@@ -120,12 +141,23 @@ if (.runThisTest) {
 	checkEquals( runit_CharacterMatrix_column(m), paste( m[,1], collapse = "" ), msg = "CharacterVector::Column" )
     }
 
+    test.CharacterMatrix.column.const <- function(){
+	m <- matrix( letters, ncol = 2 )
+	checkEquals( runit_CharacterMatrix_column_const(m), paste( m[,1], collapse = "" ), msg = "CharacterVector::Column" )
+    }
+
     test.List.column <- function(){
 	m <- lapply( 1:16, function(i) seq(from=1, to = i ) )
 	dim( m ) <- c( 4, 4 )
 	checkEquals( runit_GenericMatrix_column( m ), 1:4, msg = "List::Column" )
     }
 
+    test.List.column.const <- function(){
+	m <- lapply( 1:16, function(i) seq(from=1, to = i ) )
+	dim( m ) <- c( 4, 4 )
+	checkEquals( runit_GenericMatrix_column_const( m ), 1:4, msg = "List::Column" )
+    }
+
     test.NumericMatrix.colsum <- function( ){
         probs <- matrix(1:12,nrow=3)
         checkEquals( runit_NumericMatrix_colsum( probs ), t(apply(probs,1,cumsum)) )
@@ -210,4 +242,11 @@ if (.runThisTest) {
         checkEquals(transposeCharacter(M), t(M), msg="character transpose with row and colnames")
     }
     
+    test.Matrix.Scalar.op <- function() {
+        M <- matrix(c(1:12), 3, 4)
+        checkEquals(matrix_scalar_plus(M, 2), M + 2, msg="matrix + scalar")
+        checkEquals(matrix_scalar_plus2(M, 2), 2 + M, msg="scalar + matrix")
+        checkEquals(matrix_scalar_divide(M, 2), M / 2, msg="matrix / scalar")
+        checkEquals(matrix_scalar_divide2(M, 2), 2 / M, msg="scalar / matrix")
+    }
 }
